@@ -56,7 +56,7 @@ kind: Pod
 metadata:
   name: myapp-pod
   annotations:
-    terrascanSkip: |
+    runterrascan.io/skip: |
       [{"rule": "accurics.kubernetes.IAM.109", "comment": "reason to skip the rule"}]
 spec:
   containers:
@@ -68,7 +68,7 @@ kind: CRD
 metadata:
   generateName: myapp-pod-prefix-
   annotations:
-    terrascanSkip: |
+    runterrascan.io/skip: |
       [{"rule": "accurics.kubernetes.IAM.109", "comment": "reason to skip the rule"}]
 spec:
   containers:
@@ -124,7 +124,7 @@ func TestK8sV1ExtractResource(t *testing.T) {
 				Metadata: k8sMetadata{
 					Name: "myapp-pod",
 					Annotations: map[string]interface{}{
-						terrascanSkip: "[{\"rule\": \"accurics.kubernetes.IAM.109\", \"comment\": \"reason to skip the rule\"}]\n",
+						utils.TerrascanSkip: "[{\"rule\": \"accurics.kubernetes.IAM.109\", \"comment\": \"reason to skip the rule\"}]\n",
 					},
 				},
 			},
@@ -215,7 +215,7 @@ func TestK8sV1Normalize(t *testing.T) {
 				},
 			},
 			want: &output.ResourceConfig{
-				ID:   "kubernetes_pod.myapp-pod.default",
+				ID:   "kubernetes_pod.myapp-pod-default",
 				Name: "myapp-pod",
 				Line: 0,
 				Type: "kubernetes_pod",
@@ -224,7 +224,7 @@ func TestK8sV1Normalize(t *testing.T) {
 					"kind":       "Pod",
 					"metadata": map[string]interface{}{
 						"annotations": map[string]interface{}{
-							terrascanSkip: "[{\"rule\": \"accurics.kubernetes.IAM.109\", \"comment\": \"reason to skip the rule\"}]\n",
+							utils.TerrascanSkip: "[{\"rule\": \"accurics.kubernetes.IAM.109\", \"comment\": \"reason to skip the rule\"}]\n",
 						},
 						"name": "myapp-pod",
 					},
@@ -249,7 +249,7 @@ func TestK8sV1Normalize(t *testing.T) {
 				},
 			},
 			want: &output.ResourceConfig{
-				ID:   "kubernetes_crd.myapp-pod-prefix-.default",
+				ID:   "kubernetes_crd.myapp-pod-prefix--default",
 				Name: "myapp-pod-prefix-",
 				Line: 0,
 				Type: "kubernetes_crd",
@@ -258,7 +258,7 @@ func TestK8sV1Normalize(t *testing.T) {
 					"kind":       "CRD",
 					"metadata": map[string]interface{}{
 						"annotations": map[string]interface{}{
-							terrascanSkip: "[{\"rule\": \"accurics.kubernetes.IAM.109\", \"comment\": \"reason to skip the rule\"}]\n",
+							utils.TerrascanSkip: "[{\"rule\": \"accurics.kubernetes.IAM.109\", \"comment\": \"reason to skip the rule\"}]\n",
 						},
 						"generateName": "myapp-pod-prefix-",
 					},
@@ -328,7 +328,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with invalid terrascanSkipRules type",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: "test",
+					utils.TerrascanSkip: "test",
 				},
 			},
 			want: nil,
@@ -337,7 +337,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with invalid SkipRule object",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: []interface{}{1},
+					utils.TerrascanSkip: []interface{}{1},
 				},
 			},
 			want: nil,
@@ -346,7 +346,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with invalid terrascanSkipRules rule value",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: fmt.Sprintf(`{"%s":%d}`, terrascanSkipRule, 1),
+					utils.TerrascanSkip: fmt.Sprintf(`{"%s":%d}`, utils.TerrascanSkipRule, 1),
 				},
 			},
 			want: nil,
@@ -355,7 +355,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with one terrascanSkipRules",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: fmt.Sprintf(`[{"%s":"%s"}]`, terrascanSkipRule, testRuleA),
+					utils.TerrascanSkip: fmt.Sprintf(`[{"%s":"%s"}]`, utils.TerrascanSkipRule, testRuleA),
 				},
 			},
 			want: []output.SkipRule{
@@ -368,7 +368,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with multiple terrascanSkipRules",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: fmt.Sprintf(`[{"rule":"%s","comment":"%s"}, {"rule":"%s","comment":"%s"}, {"rule":"%s","comment":"%s"}]`, testRuleA, testCommentA, testRuleB, testCommentB, testRuleC, testCommentC),
+					utils.TerrascanSkip: fmt.Sprintf(`[{"rule":"%s","comment":"%s"}, {"rule":"%s","comment":"%s"}, {"rule":"%s","comment":"%s"}]`, testRuleA, testCommentA, testRuleB, testCommentB, testRuleC, testCommentC),
 				},
 			},
 			want: []output.SkipRule{
@@ -390,7 +390,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with invalid rule key in terrascanSkipRules",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: fmt.Sprintf(`[{"skip":"%s","comment":"%s"}]`, testRuleA, testCommentA),
+					utils.TerrascanSkip: fmt.Sprintf(`[{"skip":"%s","comment":"%s"}]`, testRuleA, testCommentA),
 				},
 			},
 			want: []output.SkipRule{{Comment: testCommentA}},
@@ -399,7 +399,7 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 			name: "annotations with no comment key in terrascanSkipRules",
 			args: args{
 				annotations: map[string]interface{}{
-					terrascanSkip: fmt.Sprintf(`[{"rule":"%s"}]`, testRuleA),
+					utils.TerrascanSkip: fmt.Sprintf(`[{"rule":"%s"}]`, testRuleA),
 				},
 			},
 			want: []output.SkipRule{testSkipRule},
@@ -407,9 +407,85 @@ func TestReadSkipRulesFromAnnotations(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			if got := readSkipRulesFromAnnotations(tt.args.annotations, tt.args.resourceID); !reflect.DeepEqual(got, tt.want) {
+			if got := utils.ReadSkipRulesFromMap(tt.args.annotations, tt.args.resourceID); !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("readSkipRulesFromAnnotations() = got %v, want %v", got, tt.want)
 			}
 		})
 	}
 }
+
+func TestReadMinMaxSeverityFromAnnotations(t *testing.T) {
+	type args struct {
+		annotations map[string]interface{}
+		resourceID  string
+	}
+	tests := []struct {
+		name            string
+		args            args
+		wantMaxSeverity string
+		wantMinSeverity string
+	}{
+		{
+			name: "no severity",
+			args: args{
+				annotations: map[string]interface{}{
+					"test": "test",
+				},
+			},
+			wantMinSeverity: "",
+			wantMaxSeverity: "",
+		},
+		{
+			name: "min severity set to high",
+			args: args{annotations: map[string]interface{}{
+				terrascanMinSeverity: "High",
+			}},
+			wantMinSeverity: "High",
+			wantMaxSeverity: "",
+		},
+		{
+			name: "max severity set to low",
+			args: args{annotations: map[string]interface{}{
+				terrascanMaxSeverity: "Low",
+			}},
+			wantMinSeverity: "",
+			wantMaxSeverity: "Low",
+		},
+		{
+			name: "max severity set to None",
+			args: args{annotations: map[string]interface{}{
+				terrascanMaxSeverity: "None"}},
+			wantMinSeverity: "",
+			wantMaxSeverity: "None",
+		},
+		{
+			name: "max severity set to low and Min severity set to high",
+			args: args{annotations: map[string]interface{}{
+				terrascanMaxSeverity: "LOw",
+				terrascanMinSeverity: "hiGh",
+			}},
+			wantMinSeverity: "hiGh",
+			wantMaxSeverity: "LOw",
+		},
+		{
+			name: "invalid min and max value",
+			args: args{annotations: map[string]interface{}{
+				terrascanMaxSeverity: 2,
+				terrascanMinSeverity: false,
+			}},
+			wantMinSeverity: "",
+			wantMaxSeverity: "",
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			gotMaxSeverity, gotMinSeverity := readMinMaxSeverityFromAnnotations(tt.args.annotations, tt.args.resourceID)
+			if gotMaxSeverity != tt.wantMaxSeverity {
+				t.Errorf("readMinMaxSeverityFromAnnotations() gotMaxSeverity = %v, want %v", gotMaxSeverity, tt.wantMaxSeverity)
+			}
+			if gotMinSeverity != tt.wantMinSeverity {
+				t.Errorf("readMinMaxSeverityFromAnnotations() gotMinSeverity = %v, want %v", gotMinSeverity, tt.wantMinSeverity)
+			}
+		})
+	}
+}
