@@ -46,6 +46,7 @@ var (
 type ModuleConfig struct {
 	Config           *hclConfigs.Config
 	ParentModuleCall *hclConfigs.ModuleCall
+	Name             string
 }
 
 // TerraformDirectoryLoader implements terraform directory loading
@@ -119,7 +120,7 @@ func (t TerraformDirectoryLoader) loadDirRecursive(dirList []string) (output.All
 		if diags.HasErrors() {
 			// log a warn message in this case because there are errors in
 			// loading the config dir, and continue with other directories
-			errMessage := fmt.Sprintf("failed to build unified config. errors:\n%+v\n", diags)
+			errMessage := fmt.Sprintf("failed to build unified config. errors:\n%+v\n", getErrorMessagesFromDiagnostics(diags))
 			zap.S().Warnf(errMessage)
 			t.addError(errMessage, dir)
 			continue
@@ -136,7 +137,7 @@ func (t TerraformDirectoryLoader) loadDirRecursive(dirList []string) (output.All
 		*/
 
 		// queue of for BFS, add root module config to it
-		root := &ModuleConfig{Config: unified.Root}
+		root := &ModuleConfig{Config: unified.Root, Name: "root"}
 		configsQ := []*ModuleConfig{root}
 
 		// using BFS traverse through all modules in the unified config tree
@@ -160,6 +161,9 @@ func (t TerraformDirectoryLoader) loadDirRecursive(dirList []string) (output.All
 					continue
 				}
 
+				// set module name
+				resourceConfig.ModuleName = current.Name
+
 				// resolve references
 				resourceConfig.Config = r.ResolveRefs(resourceConfig.Config.(jsonObj))
 
@@ -193,13 +197,7 @@ func (t TerraformDirectoryLoader) loadDirRecursive(dirList []string) (output.All
 			}
 
 			// add all current's children to the queue
-			for childName, childModule := range current.Config.Children {
-				childModuleConfig := &ModuleConfig{
-					Config:           childModule,
-					ParentModuleCall: current.Config.Module.ModuleCalls[childName],
-				}
-				configsQ = append(configsQ, childModuleConfig)
-			}
+			configsQ = append(configsQ, current.getChildConfigs()...)
 		}
 	}
 
@@ -237,7 +235,7 @@ func (t TerraformDirectoryLoader) loadDirNonRecursive() (output.AllResourceConfi
 	if diags.HasErrors() {
 		// log a warn message in this case because there are errors in
 		// loading the config dir, and continue with other directories
-		errMessage := fmt.Sprintf("failed to build unified config. errors:\n%+v\n", diags)
+		errMessage := fmt.Sprintf("failed to build unified config. errors:\n%+v\n", getErrorMessagesFromDiagnostics(diags))
 		zap.S().Warnf(errMessage)
 		return nil, multierror.Append(t.errIacLoadDirs, results.DirScanErr{IacType: "terraform", Directory: t.absRootDir, ErrMessage: ErrBuildTFConfigDir.Error()})
 	}
@@ -253,7 +251,7 @@ func (t TerraformDirectoryLoader) loadDirNonRecursive() (output.AllResourceConfi
 	*/
 
 	// queue of for BFS, add root module config to it
-	root := &ModuleConfig{Config: unified.Root}
+	root := &ModuleConfig{Config: unified.Root, Name: "root"}
 	configsQ := []*ModuleConfig{root}
 
 	// using BFS traverse through all modules in the unified config tree
@@ -276,6 +274,9 @@ func (t TerraformDirectoryLoader) loadDirNonRecursive() (output.AllResourceConfi
 				return allResourcesConfig, multierror.Append(t.errIacLoadDirs, results.DirScanErr{IacType: "terraform", Directory: t.absRootDir, ErrMessage: "failed to create ResourceConfig"})
 			}
 
+			// set module name
+			resourceConfig.ModuleName = current.Name
+
 			// resolve references
 			resourceConfig.Config = r.ResolveRefs(resourceConfig.Config.(jsonObj))
 
@@ -301,13 +302,7 @@ func (t TerraformDirectoryLoader) loadDirNonRecursive() (output.AllResourceConfi
 		}
 
 		// add all current's children to the queue
-		for childName, childModule := range current.Config.Children {
-			childModuleConfig := &ModuleConfig{
-				Config:           childModule,
-				ParentModuleCall: current.Config.Module.ModuleCalls[childName],
-			}
-			configsQ = append(configsQ, childModuleConfig)
-		}
+		configsQ = append(configsQ, current.getChildConfigs()...)
 	}
 
 	// successful
@@ -324,8 +319,11 @@ func (t TerraformDirectoryLoader) buildUnifiedConfig(rootMod *hclConfigs.Module,
 		func(req *hclConfigs.ModuleRequest) (*hclConfigs.Module, *version.Version, hcl.Diagnostics) {
 
 			// figure out path sub module directory, if it's remote then download it locally
-			var pathToModule string
-			var err error
+			var (
+				pathToModule   string
+				err            error
+				moduleDirDiags hcl.Diagnostics
+			)
 			if downloader.IsLocalSourceAddr(req.SourceAddr) {
 
 				pathToModule = t.processLocalSource(req)
@@ -349,6 +347,15 @@ func (t TerraformDirectoryLoader) buildUnifiedConfig(rootMod *hclConfigs.Module,
 				}
 			}
 
+			// verify whether the module source directory has any .tf config files
+			if utils.IsDirExists(pathToModule) && !t.parser.IsConfigDir(pathToModule) {
+				moduleDirDiags = append(moduleDirDiags, &hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Invalid module config directory",
+					Detail:   fmt.Sprintf("Module directory '%s' has no terraform config files for module %s", pathToModule, req.Name),
+				})
+				return nil, nil, moduleDirDiags
+			}
 			// load sub module directory
 			subMod, diags := t.parser.LoadConfigDir(pathToModule)
 			version, _ := version.NewVersion(fmt.Sprintf("1.0.%d", versionI))
@@ -389,3 +396,17 @@ func (t TerraformDirectoryLoader) processTerraformRegistrySource(req *hclConfigs
 
 	return pathToModule, nil
 }
+
+// getChildConfigs will get all child configs in a ModuleConfig
+func (m *ModuleConfig) getChildConfigs() []*ModuleConfig {
+	allConfigs := make([]*ModuleConfig, 0)
+	for childName, childModule := range m.Config.Children {
+		childModuleConfig := &ModuleConfig{
+			Config:           childModule,
+			ParentModuleCall: m.Config.Module.ModuleCalls[childName],
+			Name:             childName,
+		}
+		allConfigs = append(allConfigs, childModuleConfig)
+	}
+	return allConfigs
+}
