@@ -55,7 +55,7 @@ func NewEngine() (*Engine, error) {
 }
 
 // LoadRegoMetadata Loads rego metadata from a given file
-func (e *Engine) LoadRegoMetadata(metaFilename string) (*RegoMetadata, error) {
+func (e *Engine) LoadRegoMetadata(metaFilename string) (*policy.RegoMetadata, error) {
 	// Load metadata file if it exists
 	metadata, err := ioutil.ReadFile(metaFilename)
 	if err != nil {
@@ -66,7 +66,7 @@ func (e *Engine) LoadRegoMetadata(metaFilename string) (*RegoMetadata, error) {
 	}
 
 	// Read metadata into struct
-	regoMetadata := RegoMetadata{}
+	regoMetadata := policy.RegoMetadata{}
 	if err = json.Unmarshal(metadata, &regoMetadata); err != nil {
 		zap.S().Error("failed to unmarshal rego metadata", zap.String("file", metaFilename), zap.Error(err))
 		return nil, err
@@ -75,7 +75,7 @@ func (e *Engine) LoadRegoMetadata(metaFilename string) (*RegoMetadata, error) {
 }
 
 // loadRawRegoFilesIntoMap imports raw rego files into a map
-func (e *Engine) loadRawRegoFilesIntoMap(currentDir string, regoDataList []*RegoData, regoFileMap *map[string][]byte) error {
+func (e *Engine) loadRawRegoFilesIntoMap(currentDir string, regoDataList []*policy.RegoData, regoFileMap *map[string][]byte) error {
 	for i := range regoDataList {
 		regoPath := filepath.Join(currentDir, regoDataList[i].Metadata.File)
 		rawRegoData, err := ioutil.ReadFile(regoPath)
@@ -98,7 +98,7 @@ func (e *Engine) loadRawRegoFilesIntoMap(currentDir string, regoDataList []*Rego
 }
 
 // LoadRegoFiles Loads all related rego files from the given policy path into memory
-func (e *Engine) LoadRegoFiles(policyPath string) error {
+func (e *Engine) LoadRegoFiles(policyPath string, filter policy.PreLoadFilter) error {
 	// Walk the file path and find all directories
 	dirList, err := utils.FindAllDirectories(policyPath)
 	if err != nil {
@@ -110,7 +110,7 @@ func (e *Engine) LoadRegoFiles(policyPath string) error {
 	}
 
 	e.regoFileMap = make(map[string][]byte)
-	e.regoDataMap = make(map[string]*RegoData)
+	e.regoDataMap = make(map[string]*policy.RegoData)
 
 	// Load rego data files from each dir
 	// First, we read the metadata file, which contains info about the associated rego rule. The .rego file data is
@@ -134,17 +134,29 @@ func (e *Engine) LoadRegoFiles(policyPath string) error {
 			continue
 		}
 
-		var regoDataList []*RegoData
+		var regoDataList []*policy.RegoData
 		for j := range metadataFiles {
 			filePath := filepath.Join(dirList[i], *metadataFiles[j])
 
-			var regoMetadata *RegoMetadata
+			var regoMetadata *policy.RegoMetadata
 			regoMetadata, err = e.LoadRegoMetadata(filePath)
 			if err != nil {
 				zap.S().Error("error loading rego metadata", zap.String("file", filePath), zap.Error(err))
 				continue
 			}
 
+			// check if the rego metadata is allowed
+			// this check is for scan rules, categories, policy types, and severity
+			if !filter.IsAllowed(regoMetadata) {
+				continue
+			}
+
+			// check if the rego metadata should be filtered
+			// this check is for skip rules
+			if filter.IsFiltered(regoMetadata) {
+				continue
+			}
+
 			// Perform some sanity checks
 			if strings.Contains(regoMetadata.Name, ".") {
 				zap.S().Error("error loading rego metadata: rule name must not contain a dot character", zap.String("name", regoMetadata.Name), zap.String("file", filePath))
@@ -160,7 +172,7 @@ func (e *Engine) LoadRegoFiles(policyPath string) error {
 				regoMetadata.TemplateArgs["name"] = regoMetadata.Name
 			}
 
-			regoData := RegoData{
+			regoData := policy.RegoData{
 				Metadata: *regoMetadata,
 			}
 
@@ -242,20 +254,14 @@ func (e *Engine) CompileRegoFiles() error {
 
 // Init initializes the Opa engine
 // Handles loading all rules, filtering, compiling, and preparing for evaluation
-func (e *Engine) Init(policyPath string, scanRules, skipRules, categories []string, severity string) error {
+func (e *Engine) Init(policyPath string, filter policy.PreLoadFilter) error {
 	e.context = context.Background()
 
-	if err := e.LoadRegoFiles(policyPath); err != nil {
+	if err := e.LoadRegoFiles(policyPath, filter); err != nil {
 		zap.S().Error("error loading rego files", zap.String("policy path", policyPath), zap.Error(err))
 		return ErrInitFailed
 	}
 
-	// before compiling the rego files, filter the rules based on scan and skip rules, and severity level supplied
-	e.FilterRules(policyPath, scanRules, skipRules, categories, severity)
-
-	// update the rule count
-	e.stats.ruleCount = len(e.regoDataMap)
-
 	err := e.CompileRegoFiles()
 	if err != nil {
 		zap.S().Error("error compiling rego files", zap.String("policy path", policyPath), zap.Error(err))
@@ -284,7 +290,7 @@ func (e *Engine) Release() error {
 }
 
 // reportViolation Add a violation for a given resource
-func (e *Engine) reportViolation(regoData *RegoData, resource *output.ResourceConfig, isSkipped bool, skipComment string) {
+func (e *Engine) reportViolation(regoData *policy.RegoData, resource *output.ResourceConfig, isSkipped bool, skipComment string) {
 	violation := results.Violation{
 		RuleName:     regoData.Metadata.Name,
 		Description:  regoData.Metadata.Description,
@@ -296,13 +302,24 @@ func (e *Engine) reportViolation(regoData *RegoData, resource *output.ResourceCo
 		ResourceName: resource.Name,
 		ResourceType: resource.Type,
 		ResourceData: resource.Config,
+		ModuleName:   resource.ModuleName,
 		File:         resource.Source,
 		PlanRoot:     resource.PlanRoot,
 		LineNumber:   resource.Line,
 	}
 
-	if !isSkipped {
-		severity := regoData.Metadata.Severity
+	if !strings.EqualFold(resource.MaxSeverity, "none") {
+		// if both values are set then min severity will be applicable
+		if resource.MinSeverity != "" {
+			if utils.MinSeverityApplicable(regoData.Metadata.Severity, resource.MinSeverity) {
+				violation.Severity = strings.ToUpper(resource.MinSeverity)
+			}
+		} else if utils.MaxSeverityApplicable(regoData.Metadata.Severity, resource.MaxSeverity) {
+			violation.Severity = strings.ToUpper(resource.MaxSeverity)
+		}
+	}
+	if !isSkipped && !strings.EqualFold(resource.MaxSeverity, "none") {
+		severity := violation.Severity
 		if strings.ToLower(severity) == "high" {
 			e.results.ViolationStore.Summary.HighCount++
 		} else if strings.ToLower(severity) == "medium" {
@@ -322,7 +339,7 @@ func (e *Engine) reportViolation(regoData *RegoData, resource *output.ResourceCo
 }
 
 // reportPassed Adds a passed rule which wasn't violated by all the resources
-func (e *Engine) reportPassed(regoData *RegoData) {
+func (e *Engine) reportPassed(regoData *policy.RegoData) {
 	passedRule := results.PassedRule{
 		RuleName:    regoData.Metadata.Name,
 		Description: regoData.Metadata.Description,
@@ -335,16 +352,23 @@ func (e *Engine) reportPassed(regoData *RegoData) {
 }
 
 // Evaluate Executes compiled OPA queries against the input JSON data
-func (e *Engine) Evaluate(engineInput policy.EngineInput) (policy.EngineOutput, error) {
+func (e *Engine) Evaluate(engineInput policy.EngineInput, filter policy.PreScanFilter) (policy.EngineOutput, error) {
 	// Keep track of how long it takes to evaluate the policies
 	start := time.Now()
 
+	e.regoDataMap = filter.Filter(e.regoDataMap, engineInput)
+
+	// update the rule count
+	e.stats.ruleCount = len(e.regoDataMap)
+
 	// Evaluate the policy against each resource type
 	for k := range e.regoDataMap {
 		// Execute the prepared query.
 		rs, err := e.regoDataMap[k].PreparedQuery.Eval(e.context, rego.EvalInput(engineInput.InputData))
 		if err != nil {
-			zap.S().Warn("failed to run prepared query", zap.Error(err), zap.String("rule", "'"+k+"'"), zap.String("file", e.regoDataMap[k].Metadata.File))
+			// since the eval failed with the policy, we should decrement the total count by 1
+			e.stats.ruleCount--
+			zap.S().Debug("failed to run prepared query", zap.Error(err), zap.String("rule", "'"+k+"'"), zap.String("file", e.regoDataMap[k].Metadata.File))
 			continue
 		}
 
@@ -440,95 +464,3 @@ func (e *Engine) Evaluate(engineInput policy.EngineInput) (policy.EngineOutput,
 	e.results.ViolationStore.Summary.TotalTime += int64(e.stats.runTime)
 	return e.results, nil
 }
-
-// FilterRules will apply the scan and skip rules, severity level and categories
-func (e *Engine) FilterRules(policyPath string, scanRules, skipRules, categories []string, severity string) {
-	// apply scan rules
-	if len(scanRules) > 0 {
-		e.filterScanRules(policyPath, scanRules)
-	}
-
-	// apply skip rules
-	if len(skipRules) > 0 {
-		e.filterSkipRules(policyPath, skipRules)
-	}
-
-	// apply categories
-	if len(categories) > 0 {
-		e.filterByCategories(policyPath, categories)
-	}
-
-	// apply severity
-	if len(severity) > 0 {
-		e.filterBySeverity(policyPath, severity)
-	}
-}
-
-func (e *Engine) filterScanRules(policyPath string, scanRules []string) {
-
-	// temporary map to store data from original rego data map
-	tempMap := make(map[string]*RegoData)
-	for _, ruleID := range scanRules {
-		regoData, ok := e.regoDataMap[ruleID]
-		if ok {
-			zap.S().Infof("scan rule added. rule id: %+v found in policy path: %s", ruleID, policyPath)
-			tempMap[ruleID] = regoData
-		} else {
-			zap.S().Warnf("scan rule id: %+v not found in policy path: %s", ruleID, policyPath)
-		}
-	}
-	if len(tempMap) == 0 {
-		zap.S().Warnf("scan rule id's: %+v not found in policy path: %s", scanRules, policyPath)
-	}
-
-	// the regoDataMap should only contain regoData for supplied scan rules
-	e.regoDataMap = tempMap
-}
-
-func (e *Engine) filterSkipRules(policyPath string, skipRules []string) {
-	// remove rules to be skipped from the rego data map
-	for _, ruleID := range skipRules {
-		_, ok := e.regoDataMap[ruleID]
-		if ok {
-			zap.S().Infof("skip rule added. rule id: %+v found in policy path: %s", ruleID, policyPath)
-			delete(e.regoDataMap, ruleID)
-		} else {
-			zap.S().Warnf("skip rule id: %+v not found in policy path: %s", ruleID, policyPath)
-		}
-	}
-}
-
-func (e *Engine) filterByCategories(policyPath string, categories []string) {
-
-	// temporary map to store data from original rego data map
-	tempMap := make(map[string]*RegoData)
-	for ruleID, regoData := range e.regoDataMap {
-
-		if utils.CheckCategory(regoData.Metadata.Category, categories) {
-			tempMap[ruleID] = regoData
-		}
-	}
-	if len(tempMap) == 0 {
-		zap.S().Debugf("policy path: %s, doesn't have any rule matching the categories : %v", policyPath, categories)
-	}
-
-	// the regoDataMap should only contain regoData for required minimum severity level
-	e.regoDataMap = tempMap
-}
-
-func (e *Engine) filterBySeverity(policyPath string, severity string) {
-	// temporary map to store data from original rego data map
-	tempMap := make(map[string]*RegoData)
-	for ruleID, regoData := range e.regoDataMap {
-
-		if utils.CheckSeverity(regoData.Metadata.Severity, severity) {
-			tempMap[ruleID] = regoData
-		}
-	}
-	if len(tempMap) == 0 {
-		zap.S().Debugf("policy path: %s, doesn't have any rule matching the severity level : %s", policyPath, severity)
-	}
-
-	// the regoDataMap should only contain regoData for required minimum severity level
-	e.regoDataMap = tempMap
-}
